pub struct ObsBuildConfig {
pub out_dir: PathBuf,
pub cache_dir: Option<PathBuf>,
pub repo_id: Option<String>,
pub override_zip: Option<PathBuf>,
pub rebuild: bool,
pub browser: bool,
pub tag: Option<String>,
pub skip_compatibility_check: bool,
pub remove_pdbs: bool,
}Expand description
Configuration options for building OBS binaries
Fields
out_dir: PathBufThe directory the libobs binaries should be installed to (this is typically your target/debug or target/release directory)
cache_dir: Option<PathBuf>The location where the OBS Studio binaries should be downloaded to. If this is set to None, it defaults to reading the Cargo.toml metadata. If no metadata is set, it defaults to obs-build.
repo_id: Option<String>The GitHub repository to clone OBS Studio from, if not specified it defaults to obsproject/obs-studio
override_zip: Option<PathBuf>If this is specified, the specified zip file will be used instead of downloading the latest release This is useful for testing purposes, but it is not recommended to use this in production
rebuild: boolWhen this flag is active, the cache will be cleared and a new build will be started
browser: boolIf the browser should be included in the build
tag: Option<String>The tag of the OBS Studio release to build.
If none is specified, first the Cargo.toml metadata will be checked, if the version is not set it’ll find the matching release for the libobs crate will be used.
Use latest for the latest obs release.
skip_compatibility_check: boolIf the compatibility check should be skipped
remove_pdbs: boolIf set, PDBs will be deleted after extraction to save space, saving disk space.